@@ -1,5 +1,5 @@
 /*
- *     (C) Copyright 2012 Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,7 @@
  *
  */
 
-/*global CatalogueResource, gettext, interpolate, LayoutManagerFactory, OpManagerFactory, Wirecloud, Template*/
+/*global CatalogueResource, gettext, Wirecloud*/
 
 (function () {
 
@@ -28,29 +28,19 @@
     var WirecloudCatalogue, _onSearchSuccess, _onSearchError, deleteSuccessCallback, deleteErrorCallback;
 
     _onSearchSuccess = function _onSearchSuccess(transport) {
-        var preferred_versions, i, data, key, raw_data, resources, resource;
+        var i, data, raw_data, resources, resource;
 
         raw_data = JSON.parse(transport.responseText);
         if (raw_data.resources) {
-            preferred_versions = Wirecloud.utils.CookieManager.readCookie('preferred_versions', true);
-            if (preferred_versions === null) {
-                preferred_versions = {};
-            }
-
             resources = [];
 
             for (i = 0; i < raw_data.resources.length; i += 1) {
                 resource = new CatalogueResource(raw_data.resources[i]);
                 resources.push(resource);
-                key = resource.vendor + '/' + resource.name;
-                if (key in preferred_versions) {
-                    resource.changeVersion(preferred_versions[key]);
-                }
             }
 
             data = {
                 'resources': resources,
-                'preferred_versions': preferred_versions,
                 'current_page': this.options.starting_page,
                 'total_count': parseInt(raw_data.items, 10)
             };
@@ -59,11 +49,11 @@
         }
     };
 
-    _onSearchError = function _onSearchError(transport) {
+    _onSearchError = function _onSearchError() {
         this.onError();
     };
 
-    deleteSuccessCallback = function deleteSuccessCallback(transport) {
+    deleteSuccessCallback = function deleteSuccessCallback() {
         this.onSuccess();
     };
 
@@ -85,11 +75,11 @@
             options.url += '/';
         }
 
-        this.view_all_template = new Template(options.url + 'catalogue/resources/#{starting_page}/#{resources_per_page}');
-        this.simple_search_template = new Template(options.url + 'catalogue/search/and/#{starting_page}/#{resources_per_page}');
+        this.view_all_template = new Wirecloud.Utils.Template(options.url + 'catalogue/resources/%(starting_page)s/%(resources_per_page)s');
+        this.simple_search_template = new Wirecloud.Utils.Template(options.url + 'catalogue/search/and/%(starting_page)s/%(resources_per_page)s');
 
         Object.defineProperty(this, 'RESOURCE_ENTRY', {
-            value: new Template(options.url + 'catalogue/resource/#{vendor}/#{name}/#{version}')
+            value: new Wirecloud.Utils.Template(options.url + 'catalogue/resource/%(vendor)s/%(name)s/%(version)s')
         });
         Object.defineProperty(this, 'RESOURCE_COLLECTION', {value: options.url + 'catalogue/resources'});
     };
@@ -120,25 +110,30 @@
             'onError': onError
         };
 
-        if (options.search_criteria.strip() === '') {
+        if (options.search_criteria.trim() === '') {
             url = this.view_all_template.evaluate({'starting_page': options.starting_page, 'resources_per_page': options.resources_per_page});
         } else {
             url = this.simple_search_template.evaluate({'starting_page': options.starting_page, 'resources_per_page': options.resources_per_page});
         }
         Wirecloud.io.makeRequest(url, {
             method: 'GET',
+            requestHeaders: {'Accept': 'application/json'},
             parameters: params,
             onSuccess: _onSearchSuccess.bind(context),
             onFailure: _onSearchError.bind(context)
         });
     };
 
-    WirecloudCatalogue.prototype.is_purchased = function is_purchased(resource) {
+    WirecloudCatalogue.prototype.is_purchased = function is_purchased() {
         return true;
     };
 
     WirecloudCatalogue.prototype.addPackagedResource = function addPackagedResource(data, options) {
-        var url, requestHeaders;
+        var url, requestHeaders, task, onUploadProgress;
+
+        requestHeaders = {
+            'Accept': 'application/json'
+        };
 
         if (typeof options != 'object') {
             options = {};
@@ -151,12 +146,17 @@
 
 
             if (this.accesstoken != null) {
-                requestHeaders = {
-                    'Authorization': 'Bearer ' + self.accesstoken
-                };
+                requestHeaders['Authorization'] = 'Bearer ' + this.accesstoken;
             }
         }
 
+        if (options.monitor) {
+            task = options.monitor.nextSubtask(gettext('Uploading packaged resource'));
+            onUploadProgress = function (event) {
+                task.updateTaskProgress(Math.round(event.loaded * 100 / event.total));
+            };
+        }
+
         Wirecloud.io.makeRequest(url, {
             method: 'POST',
             requestHeaders: requestHeaders,
@@ -185,7 +185,8 @@
                         options.onComplete();
                     } catch (e) {}
                 }
-            }
+            },
+            onUploadProgress: onUploadProgress
         });
     };
 
@@ -196,8 +197,9 @@
 
         Wirecloud.io.makeRequest(this.RESOURCE_COLLECTION, {
             method: 'POST',
+            requestHeaders: {'Accept': 'application/json'},
             parameters: {'template_uri': url, packaged: !!options.packaged, force_create: !!options.forceCreate},
-            onSuccess: function (transport) {
+            onSuccess: function () {
                 if (typeof options.onSuccess === 'function') {
                     options.onSuccess();
                 }
@@ -236,6 +238,7 @@
         // Send request to delete de widget
         Wirecloud.io.makeRequest(url, {
             method: 'DELETE',
+            requestHeaders: {'Accept': 'application/json'},
             onSuccess: deleteSuccessCallback.bind(context),
             onFailure: deleteErrorCallback.bind(context),
             onException: deleteErrorCallback.bind(context)
