@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
 from wirecloud.commons.utils.testcases import WirecloudSeleniumTestCase
 
 __test__ = False
@@ -37,13 +36,6 @@ class CatalogueSeleniumTests(WirecloudSeleniumTestCase):
 
         self.add_packaged_resource_to_catalogue('Wirecloud_PackagedTestMashup_1.0.zip', 'PackagedTestMashup', shared=True)
 
-    def test_widgets_are_deletable_by_the_uploader(self):
-
-        self.login('normuser', 'admin')
-
-        self.add_packaged_resource_to_catalogue('Wirecloud_Test_Selenium_1.0.wgt', 'Test_Selenium', shared=True)
-        self.delete_resource('Test_Selenium')
-
     def test_reinstall_widget_to_catalog_wgt(self):
 
         self.login()
@@ -68,7 +60,7 @@ class CatalogueSeleniumTests(WirecloudSeleniumTestCase):
 
         self.login()
 
-        self.add_template_to_catalogue('http://localhost:8001/test/invalidTest.rdf', 'Test_Selenium', expect_error='missing required field: versionInfo.')
+        self.add_template_to_catalogue('http://localhost:8001/test/invalidTest.rdf', 'Test_Selenium', expect_error='Error parsing resource descriptor from the providen URL: missing required field: versionInfo.')
 
     def test_add_widget_twice(self):
 
@@ -95,3 +87,17 @@ class CatalogueSeleniumTests(WirecloudSeleniumTestCase):
 
         self.add_template_to_catalogue('http://localhost:8001/test/test.rdf', 'Test_Selenium')
         self.delete_resource('Test_Selenium')
+
+    def test_search_empty_results(self):
+
+        self.login()
+
+        self.search_resource('nousedkeyword')
+        catalogue_base_element = self.get_current_catalogue_base_element()
+
+        resources = catalogue_base_element.find_elements_by_css_selector('.resource_list .resource')
+        self.assertEqual(len(resources), 0)
+
+        alert = catalogue_base_element.find_elements_by_css_selector('.alert')
+        self.assertEqual(len(alert), 1)
+        self.assertIn('nousedkeyword', alert[0].text)
