@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
 import codecs
 import json
 import os
@@ -218,26 +217,6 @@ class CatalogueAPITestCase(TestCase):
         self.assertEqual(len(result_json['resources']), 1)
         self.assertEqual(result_json['resources'][0]['lastVersion'], '1.10')
 
-    def test_vote_queries(self):
-
-        User.objects.create_user('test2', 'test@example.com', 'test')
-        vote_url = reverse('wirecloud_catalogue.resource_vote', kwargs={'vendor': 'Test', 'name': 'widget1', 'version': '1.2'})
-
-        self.client.login(username='test', password='test')
-        result = self.client.post(vote_url, json.dumps({'vote': 3}), **self.basic_request_meta)
-        self.assertEqual(result.status_code, 200)
-
-        self.client.login(username='test2', password='test')
-        result = self.client.post(vote_url, json.dumps({'vote': 4}), **self.basic_request_meta)
-        self.assertEqual(result.status_code, 200)
-
-        result_json = json.loads(result.content)
-        self.assertTrue('voteData' in result_json)
-        self.assertTrue('popularity' in result_json['voteData'])
-        self.assertEqual(result_json['voteData']['popularity'], '3.5')
-        self.assertTrue('user_vote' in result_json['voteData'])
-        self.assertEqual(result_json['voteData']['user_vote'], 4)
-
 
 class PublishTestCase(WirecloudTestCase):
 
