@@ -4,6 +4,7 @@
 "use strict";
 
 var OK_HTML = '<b>Success!!</b>';
+var FAILURE_HTML = '<b>Failure!!</b>';
 
 MashupPlatform.http.makeRequest('data/success.html', {
     method: 'GET',
@@ -16,8 +17,8 @@ MashupPlatform.http.makeRequest('data/success.html', {
 
 MashupPlatform.http.makeRequest('http://example.com/success.html', {
     method: 'GET',
-    onSuccess: function (transport) {
-        if (transport.responseText === 'remote makerequest succeded') {
+    onSuccess: function (response) {
+        if (response.status === 200 && response.responseText === 'remote makerequest was successful') {
             document.getElementById('makerequest_test').innerHTML = OK_HTML;
         }
     }
@@ -29,7 +30,11 @@ MashupPlatform.wiring.registerCallback('inputendpoint', function (data) {
 MashupPlatform.wiring.pushEvent('outputendpoint', 'Success!!');
 
 MashupPlatform.prefs.registerCallback(function (new_values) {
-    document.getElementById('pref_registercallback_test').innerHTML = new_values.text;
+    if (Object.keys(new_values).length == 1 && 'text' in new_values) {
+        document.getElementById('pref_registercallback_test').innerHTML = new_values.text;
+    } else {
+        document.getElementById('pref_registercallback_test').innerHTML = FAILURE_HTML;
+    }
 });
 
 setTimeout(function () {
@@ -42,12 +47,35 @@ setTimeout(function () {
         document.getElementById('widget_log_test').innerHTML = OK_HTML;
     };
 
+    document.getElementById('check_preference_exceptions_button').onclick = function () {
+        var success_count = 0;
+        try {
+            MashupPlatform.prefs.get('nonexistent');
+        } catch (error) {
+            if (error instanceof MashupPlatform.prefs.PreferenceError) {
+                success_count += 1;
+            }
+        }
+
+        try {
+            MashupPlatform.prefs.set('nonexistent');
+        } catch (error) {
+            if (error instanceof MashupPlatform.prefs.PreferenceError) {
+                success_count += 1;
+            }
+        }
+
+        if (success_count === 2) {
+            document.getElementById('preference_exceptions_test').innerHTML = OK_HTML;
+        }
+    };
+
     document.getElementById('check_endpoint_exceptions_button').onclick = function () {
         var success_count = 0;
         try {
             MashupPlatform.wiring.pushEvent('nonexistent', '');
         } catch (error) {
-            if (error instanceof MashupPlatform.wiring.EndpointException) {
+            if (error instanceof MashupPlatform.wiring.EndpointError) {
                 success_count += 1;
             }
         }
@@ -55,7 +83,7 @@ setTimeout(function () {
         try {
             MashupPlatform.wiring.getReachableEndpoints('nonexistent');
         } catch (error) {
-            if (error instanceof MashupPlatform.wiring.EndpointException) {
+            if (error instanceof MashupPlatform.wiring.EndpointError) {
                 success_count += 1;
             }
         }
@@ -63,7 +91,7 @@ setTimeout(function () {
         try {
             MashupPlatform.wiring.registerCallback('nonexistent', function () {});
         } catch (error) {
-            if (error instanceof MashupPlatform.wiring.EndpointException) {
+            if (error instanceof MashupPlatform.wiring.EndpointError) {
                 success_count += 1;
             }
         }
