@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2013-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -20,6 +20,8 @@
 import os
 import sys
 
+from django.core.urlresolvers import reverse_lazy
+
 
 class NoseArgs(object):
 
@@ -55,9 +57,10 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
 
     settings['TEMPLATE_DEBUG'] = settings['DEBUG']
     settings['COMPRESS'] = not settings['DEBUG']
-    settings['COMPRESS_OFFLINE'] = True
+    settings['COMPRESS_OFFLINE'] = False
     settings['APPEND_SLASH'] = False
     settings['COMPRESS_OUTPUT_DIR'] = 'cache'
+    settings['ALLOW_ANONYMOUS_ACCESS'] = True
 
     settings['USE_TZ'] = True
 
@@ -131,6 +134,7 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
         'django.core.context_processors.static',
         'django.core.context_processors.tz',
         'django.contrib.messages.context_processors.messages',
+        'wirecloud.platform.context_processors.plugins',
         'wirecloud.platform.themes.active_theme_context_processor',
     )
 
@@ -165,7 +169,7 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
                 'handlers': ['console'],
             },
             'django.request': {
-                'handlers': ['mail_admins'],
+                'handlers': ['console', 'mail_admins'],
                 'level': 'ERROR',
                 'propagate': False,
             },
@@ -178,4 +182,7 @@ def load_default_wirecloud_conf(settings, instance_type='platform'):
         }
     }
 
+    settings['LOGIN_REDIRECT_URL'] = reverse_lazy('wirecloud.root')
+    settings['LOGOUT_REDIRECT_URL'] = reverse_lazy('wirecloud.root')
+
     settings['NOSE_ARGS'] = NoseArgs(instance_type)
