@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -25,7 +25,6 @@ from wirecloud.commons.utils.template.base import is_valid_name, is_valid_vendor
 from wirecloud.commons.utils.translation import get_trans_index
 
 
-EZWEB_TEMPLATE_NS = 'http://morfeo-project.org/2007/Template'
 WIRECLOUD_TEMPLATE_NS = 'http://wirecloud.conwet.fi.upm.es/ns/template#'
 
 RESOURCE_DESCRIPTION_XPATH = '/t:Template/t:Catalog.ResourceDescription'
@@ -40,6 +39,8 @@ IMAGE_URI_XPATH = 't:ImageURI'
 IPHONE_IMAGE_URI_XPATH = 't:iPhoneImageURI'
 MAIL_XPATH = 't:Mail'
 DOC_URI_XPATH = 't:WikiURI'
+LICENCE_XPATH = 't:License'
+LICENCE_URL_XPATH = 't:LicenseURL'
 REQUIREMENTS_XPATH = 't:Requirements'
 
 FEATURE_XPATH = 't:Feature'
@@ -49,11 +50,8 @@ PREFERENCES_XPATH = '/t:Template/t:Platform.Preferences[1]/t:Preference'
 OPTION_XPATH = 't:Option'
 PROPERTY_XPATH = '/t:Template/t:Platform.StateProperties[1]/t:Property'
 WIRING_XPATH = '/t:Template/t:Platform.Wiring'
-SLOT_XPATH = 't:Slot | t:InputEndpoint'
-EVENT_XPATH = 't:Event | t:OutputEndpoint'
-CONTEXT_XPATH = '/t:Template/t:Platform.Context'
-WIDGET_CONTEXT_XPATH = 't:GadgetContext | t:WidgetContext'
-PLATFORM_CONTEXT_XPATH = 't:Context'
+INPUT_ENDPOINT_XPATH = 't:InputEndpoint'
+OUTPUT_ENDPOINT_XPATH = 't:OutputEndpoint'
 PLATFORM_RENDERING_XPATH = '/t:Template/t:Platform.Rendering'
 
 INCLUDED_RESOURCES_XPATH = 't:IncludedResources'
@@ -93,14 +91,15 @@ class WirecloudTemplateParser(object):
         else:
             self._doc = template
 
-        prefix = self._doc.prefix
-        xmlns = None
-        if prefix in self._doc.nsmap:
-            xmlns = self._doc.nsmap[prefix]
+        root_element_qname = etree.QName(self._doc)
+        xmlns = root_element_qname.namespace
 
-        if xmlns is not None and xmlns not in (EZWEB_TEMPLATE_NS, WIRECLOUD_TEMPLATE_NS):
+        if xmlns is not None and xmlns != WIRECLOUD_TEMPLATE_NS:
             raise TemplateParseException("Invalid namespace: " + xmlns)
 
+        if root_element_qname.localname != 'Template':
+            raise TemplateParseException("Invalid root element: " + root_element_qname.localname)
+
         self._namespace = xmlns
 
     def _init(self):
@@ -175,20 +174,19 @@ class WirecloudTemplateParser(object):
         if not is_valid_version(self._info['version']):
             raise TemplateParseException(_('ERROR: the format of the version number is invalid. Format: X.X.X where X is an integer. Ex. "0.1", "1.11" NOTE: "1.01" should be changed to "1.0.1" or "1.1"'))
 
-        self._info['display_name'] = self._get_field(DISPLAY_NAME_XPATH, self._resource_description, required=False)
-        self._add_translation_index(self._info['display_name'], type='resource', field='display_name')
-
-        if not self._info['display_name']:
-            self._info['display_name'] = self._info['name']
+        self._info['title'] = self._get_field(DISPLAY_NAME_XPATH, self._resource_description, required=False)
+        self._add_translation_index(self._info['title'], type='resource', field='title')
 
         self._info['description'] = self._get_field(DESCRIPTION_XPATH, self._resource_description, required=False)
         self._add_translation_index(self._info['description'], type='resource', field='description')
 
-        self._info['author'] = self._get_field(AUTHOR_XPATH, self._resource_description, required=False)
+        self._info['authors'] = self._get_field(AUTHOR_XPATH, self._resource_description, required=False)
         self._info['email'] = self._get_field(MAIL_XPATH, self._resource_description)
-        self._info['image_uri'] = self._get_field(IMAGE_URI_XPATH, self._resource_description, required=False)
-        self._info['iphone_image_uri'] = self._get_field(IPHONE_IMAGE_URI_XPATH, self._resource_description, required=False)
-        self._info['doc_uri'] = self._get_field(DOC_URI_XPATH, self._resource_description, required=False)
+        self._info['image'] = self._get_field(IMAGE_URI_XPATH, self._resource_description, required=False)
+        self._info['smartphoneimage'] = self._get_field(IPHONE_IMAGE_URI_XPATH, self._resource_description, required=False)
+        self._info['doc'] = self._get_field(DOC_URI_XPATH, self._resource_description, required=False)
+        self._info['license'] = self._get_field(LICENCE_XPATH, self._resource_description, required=False)
+        self._info['licenseurl'] = self._get_field(LICENCE_URL_XPATH, self._resource_description, required=False)
         self._parse_requirements()
 
     def _parse_requirements(self):
@@ -219,7 +217,7 @@ class WirecloudTemplateParser(object):
             return
         wiring_element = wiring_elements[0]
 
-        for slot in self._xpath(SLOT_XPATH, wiring_element):
+        for slot in self._xpath(INPUT_ENDPOINT_XPATH, wiring_element):
             self._add_translation_index(slot.get('label'), type='vdef', variable=slot.get('name'))
             self._add_translation_index(slot.get('actionlabel', ''), type='vdef', variable=slot.get('name'))
             self._add_translation_index(slot.get('description', ''), type='vdef', variable=slot.get('name'))
@@ -232,7 +230,7 @@ class WirecloudTemplateParser(object):
                 'friendcode': slot.get('friendcode'),
             })
 
-        for event in self._xpath(EVENT_XPATH, wiring_element):
+        for event in self._xpath(OUTPUT_ENDPOINT_XPATH, wiring_element):
             self._add_translation_index(event.get('label'), type='vdef', variable=event.get('name'))
             self._add_translation_index(event.get('description', ''), type='vdef', variable=event.get('name'))
             self._info['wiring']['outputs'].append({
@@ -314,7 +312,7 @@ class WirecloudTemplateParser(object):
                 'label': preference.get('label'),
                 'description': preference.get('description', ''),
                 'readonly': preference.get('readonly', 'false').lower() == 'true',
-                'default_value': preference.get('default', ''),
+                'default': preference.get('default', ''),
                 'value': preference.get('value'),
                 'secure': preference.get('secure', 'false').lower() == 'true',
             }
@@ -340,34 +338,12 @@ class WirecloudTemplateParser(object):
                 'type': prop.get('type'),
                 'label': prop.get('label'),
                 'description': prop.get('description', ''),
-                'default_value': prop.get('default', ''),
+                'default': prop.get('default', ''),
                 'secure': prop.get('secure', 'false').lower() == 'true',
             })
 
         self._parse_wiring_info()
 
-        self._info['context'] = []
-
-        context_elements = self._xpath(CONTEXT_XPATH, self._doc)
-        if len(context_elements) == 1:
-
-            context_element = context_elements[0]
-
-            for wcontext in self._xpath(WIDGET_CONTEXT_XPATH, context_element):
-                self._info['context'].append({
-                    'name': wcontext.get('name'),
-                    'type': wcontext.get('type'),
-                    'concept': wcontext.get('concept'),
-                    'aspect': 'GCTX',
-                })
-            for pcontext in self._xpath(PLATFORM_CONTEXT_XPATH, context_element):
-                self._info['context'].append({
-                    'name': pcontext.get('name'),
-                    'type': pcontext.get('type'),
-                    'concept': pcontext.get('concept'),
-                    'aspect': 'ECTX',
-                })
-
         xhtml_elements = self._xpath(CODE_XPATH, self._doc)
         if len(xhtml_elements) == 1 and xhtml_elements[0].get('href', '') != '':
             xhtml_element = xhtml_elements[0]
