@@ -1,31 +1,26 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
-# This file is part of Wirecluod.
+# This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
 import rdflib
-import urllib2
-from urllib2 import HTTPError
 
 from django.utils.translation import ugettext as _
 
-from wirecloud.commons.utils.template import TemplateParser
-from wirecloud.proxy.views import MethodRequest
 
 FOAF = rdflib.Namespace('http://xmlns.com/foaf/0.1/')
 RDF = rdflib.Namespace('http://www.w3.org/1999/02/22-rdf-syntax-ns#')
@@ -49,6 +44,18 @@ DOAP = rdflib.Namespace('http://usefulinc.com/ns/doap#')
 GEO = rdflib.Namespace('http://www.w3.org/2003/01/geo/wgs84_pos#')
 
 
+class USDLParseException(Exception):
+
+    def __init__(self, msg=''):
+        self.msg = msg
+
+    def __str__(self):
+        return str(self.msg)
+
+    def __unicode__(self):
+        return unicode(self.msg)
+
+
 class USDLParser(object):
 
     _usdl_document = None
@@ -64,14 +71,19 @@ class USDLParser(object):
         self._service_number = 0
         self._graph = rdflib.Graph()
 
-        #Check rdf format
         if mime_type == 'application/rdf+xml':
-            self._graph.parse(data=usdl_document, format="application/rdf+xml")
-        elif mime_type == 'text/n3' or mime_type == 'text/turtle' or mime_type == 'text/plain':
-            self._graph.parse(data=usdl_document, format='n3')
+            rdf_format = 'xml'
+        elif mime_type == 'text/n3' or mime_type == 'text/turtle':
+            rdf_format = 'n3'
         else:
             msg = _('Error the document has not a valid rdf format')
-            raise Exception(msg)
+            raise USDLParseException(msg)
+
+        try:
+            self._graph.parse(data=usdl_document, format=rdf_format)
+        except Exception as e:
+            msg = _('Error parsing rdf document: %s' % unicode(e))
+            raise USDLParseException(msg)
 
         # take all the services in the document
         for ser in self._graph.subjects(RDF['type'], USDL['Service']):
@@ -80,7 +92,7 @@ class USDLParser(object):
 
         if self._service_number == 0:
             msg = _('Error the document is not a valid usdl document')
-            raise Exception(msg)
+            raise USDLParseException(msg)
 
     def _get_field(self, namespace, element, predicate, id_=False):
 
@@ -120,7 +132,7 @@ class USDLParser(object):
             self._info['vcard'] = {
                 'BEGIN': [{
                     'properties': {},
-                    'value':'VCARD',
+                    'value': 'VCARD',
                 }],
                 'FN': [{
                     'properties': {},
@@ -146,47 +158,9 @@ class USDLParser(object):
 
         self._info['name'] = self._get_field(DCTERMS, service_uri, 'title')[0]
 
-        display_name = None
         artefact = self._get_field(USDL, service_uri, 'utilizedResource', id_=True)[0]
         uri_template = self._get_field(BLUEPRINT, artefact, 'location')[0]
         version = self._get_field(USDL, service_uri, 'versionInfo')[0]
-        # if the document does no have a uri_template is not a widget or operator
-        if uri_template == '':
-            self._info['type'] = 'other'
-        else:
-            # To know if is a widget an operator or another kind of service using an artefact
-            # is necesary to download the technical description
-
-            opener = urllib2.build_opener()
-            headers = {"Accept": "text/plain; application/rdf+xml; text/turtle; text/n3"}
-            request = MethodRequest('GET', uri_template.encode('utf-8'), '', headers)
-            try:
-                response = opener.open(request)
-                if response.code != 200:
-                    self._info['type'] = 'other'
-                else:
-                    content = response.read()
-                    parser = TemplateParser(content)
-                    technical_info = parser.get_resource_basic_info()
-                    self._info['type'] = technical_info['type']
-                    display_name = technical_info['display_name']
-                    version = technical_info['version']
-                    self._info['name'] = technical_info['name']
-                    # if the service is a mashup it may has parts
-                    if self._info['type'] == 'mashup':
-                        service_parts = self._get_field(USDL, service_uri, 'hasPartMandatory', id_=True)
-
-                        self._info['parts'] = []
-                        for part in service_parts:
-                            part_info = {}
-                            part_info['name'] = self._get_field(DCTERMS, part, 'title')[0]
-                            part_info['uri'] = unicode(part)
-                            self._info['parts'].append(part_info)
-            except HTTPError:
-                self._info['type'] = 'other'
-
-        if self._info['type'] == 'other':
-            display_name = self._info['name']
 
         self._info.update({
             'shortDescription': self._get_field(DCTERMS, service_uri, 'abstract')[0],
@@ -195,7 +169,7 @@ class USDLParser(object):
             'version': version,
             'uriTemplate': uri_template,
             'page': self._get_field(FOAF, service_uri, 'page')[0],
-            'displayName': display_name,
+            'displayName': self._info['name'],
         })
 
     def _parse_legal_info(self, service_uri):
