@@ -135,9 +135,9 @@ class FiWarePlugin(WirecloudPlugin):
             return common + (
                 "js/wirecloud/FiWare.js",
                 "js/wirecloud/FiWare/FiWareCatalogueView.js",
-                "js/wirecloud/FiWare/FiWareCatalogue.js",
-                "js/wirecloud/FiWare/FiWareCatalogueResource.js",
-                "js/wirecloud/FiWare/ui/ResourceDetailsView.js",
+                "js/wirecloud/FiWare/Marketplace.js",
+                "js/wirecloud/FiWare/Offering.js",
+                "js/wirecloud/FiWare/ui/OfferingDetailsView.js",
                 "js/wirecloud/FiWare/ui/OfferingPainter.js",
                 "js/wirecloud/FiWare/ui/OfferingResourcesPainter.js",
                 "js/wirecloud/FiWare/FiWareResourceDetailsExtraInfo.js",
@@ -212,6 +212,7 @@ class FiWarePlugin(WirecloudPlugin):
     def get_ajax_endpoints(self, views):
         return (
             {'id': 'FIWARE_RESOURCES_COLLECTION', 'url': build_url_template('wirecloud.fiware.market_resource_collection', ['market_user', 'market_name'])},
+            {'id': 'FIWARE_OFFERING_ENTRY', 'url': build_url_template('wirecloud.fiware.market_offering_entry', ['market_user', 'market_name', 'store', 'offering_id'])},
             {'id': 'FIWARE_FULL_SEARCH', 'url': build_url_template('wirecloud.fiware.market_full_search', ['market_user', 'market_name', 'search_string'])},
             {'id': 'FIWARE_STORE_RESOURCES_COLLECTION', 'url': build_url_template('wirecloud.fiware.store_resource_collection', ['market_user', 'market_name', 'store'])},
             {'id': 'FIWARE_STORE_SEARCH', 'url': build_url_template('wirecloud.fiware.store_search', ['market_user', 'market_name', 'store', 'search_string'])},
