@@ -19,7 +19,7 @@
  *
  */
 
-/*global OpManagerFactory, StyledElements, gettext, interpolate, LayoutManagerFactory, CatalogueSearchView, Wirecloud, FiWareCatalogueResource*/
+/*global StyledElements, gettext, interpolate, LayoutManagerFactory, CatalogueSearchView, Wirecloud*/
 
 (function () {
 
@@ -51,6 +51,27 @@
         this.storeSelect.addEntries(entries);
     };
 
+    var onBuySuccess = function onBuySuccess(offering) {
+        this.viewsByName.search.mark_outdated();
+        this.catalogue.get_offering_info(offering.store, offering.marketName, {
+            onSuccess: function (refreshed_offering) {
+                refreshed_offering.install({
+                    onResourceSuccess: function (resource) {
+                        var local_catalogue_view = LayoutManagerFactory.getInstance().viewsByName.marketplace.viewsByName.local;
+                        local_catalogue_view.viewsByName.search.mark_outdated();
+                    },
+                    onFailure: function (msg) {
+                        (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
+                    },
+                    onComplete: function () {
+                        this.refresh_search_results();
+                    }.bind(this)
+                });
+            }.bind(this),
+            onFailure: this.refresh_search_results.bind(this)
+        });
+    };
+
     var FiWareCatalogueView = function (id, options) {
         var search_view_options;
 
@@ -87,11 +108,11 @@
         this.viewsByName = {
             'initial': this.alternatives.createAlternative(),
             'search': this.alternatives.createAlternative({alternative_constructor: CatalogueSearchView, containerOptions: search_view_options}),
-            'details': this.alternatives.createAlternative({alternative_constructor: Wirecloud.FiWare.ui.ResourceDetailsView, containerOptions: {catalogue: this}})
+            'details': this.alternatives.createAlternative({alternative_constructor: Wirecloud.FiWare.ui.OfferingDetailsView, containerOptions: {catalogue: this}})
         };
         this.viewsByName.search.init();
 
-        this.catalogue = new Wirecloud.FiWare.FiWareCatalogue(this.desc);
+        this.catalogue = new Wirecloud.FiWare.Marketplace(this.desc);
         this.number_of_stores = 0;
         this.refresh_store_info();
         this.addEventListener('show', function () {
@@ -128,15 +149,14 @@
     };
 
     FiWareCatalogueView.prototype._onSearch = function (callback, raw_data) {
-        var i, data, resources, resource;
+        var i, data, resources;
 
         if (raw_data.resources) {
 
             resources = [];
 
             for (i = 0; i < raw_data.resources.length; i += 1) {
-                resource = new FiWareCatalogueResource(raw_data.resources[i]);
-                resources.push(resource);
+                resources.push(new Wirecloud.FiWare.Offering(raw_data.resources[i], this.catalogue));
             }
 
             data = {
@@ -230,16 +250,16 @@
         }.bind(this);
     };
 
-    FiWareCatalogueView.prototype.ui_commands.buy = function (resource) {
+    FiWareCatalogueView.prototype.ui_commands.buy = function (offering) {
         return function () {
-            this.catalogue.start_purchase(resource, {
+            this.catalogue.start_purchase(offering, {
                 onSuccess: function (data) {
                     var dialog = new Wirecloud.ui.ExternalProcessWindowMenu(
-                        interpolate(gettext('Buying %(offering)s'), {offering: resource.getDisplayName()}, true),
+                        interpolate(gettext('Buying %(offering)s'), {offering: offering.getDisplayName()}, true),
                         data.url,
                         gettext('The buying process will continue in a separate window. This window will be controled by the store where the offering is hosted. After finishing the buying process, the control will return to Wirecloud.'),
                         {
-                            onSuccess: this.refresh_search_results.bind(this)
+                            onSuccess: onBuySuccess.bind(this, offering)
                         }
                     );
                     dialog.show();
