@@ -120,6 +120,22 @@ class FiWareSeleniumTestCase(WirecloudSeleniumTestCase):
             self.assertEqual(api_element.text, 'Yes')
     test_objectstorage_available_to_widgets.tags = ('fiware', 'fiware-plugin', 'fiware-ut-12')
 
+    @uses_extra_resources(('Wirecloud_objectstorage-test-widget_1.0.wgt',))
+    def test_objectstorage_reports_failures(self):
+
+        self.login()
+
+        with self.add_widget_to_mashup('Wirecloud Object Storage API test widget'):
+            api_element = self.driver.find_element_by_id('api_available')
+            self.assertEqual(api_element.text, 'Yes')
+            self.driver.find_element_by_css_selector('.btn-primary > div').click()
+            WebDriverWait(self.driver, 10).until(lambda driver: driver.find_element_by_css_selector('.btn-primary:not(.disabled)'))
+
+            tenant_id_step = self.driver.find_element_by_id('tenantId')
+            self.assertEqual(tenant_id_step.text, 'Fail')
+            alert = self.driver.find_element_by_css_selector('.alert-error')
+            self.assertEqual(alert.text, 'Failure!')
+
     def test_marketplace_keyword_search(self):
 
         response_text = read_response_file('responses', 'marketplace', 'keyword_search.xml')
@@ -253,6 +269,8 @@ class FiWareSeleniumTestCase(WirecloudSeleniumTestCase):
         response_text = read_response_file('responses', 'marketplace', 'keyword_search.xml')
         self.network._servers['http']['marketplace.example.com'].add_response('GET', '/search/offerings/fulltext/test', {'content': response_text})
         self.network._servers['http']['store2.example.com'].add_response('POST', '/api/contracting/form', {'content': str('{"url": "' + self.live_server_url + '"}')})
+        response_text = read_response_file('responses', 'marketplace', 'store2_weatherwidget_offering.xml')
+        self.network._servers['http']['marketplace.example.com'].add_response('GET', '/offering/store/Store%202/offering/WeatherWidget', {'content': response_text})
 
         self.login(username='user_with_markets')
 
@@ -270,7 +288,7 @@ class FiWareSeleniumTestCase(WirecloudSeleniumTestCase):
 
         free_offering = self.search_in_catalogue_results('Weather widget')
         button = free_offering.find_element_by_css_selector('.mainbutton')
-        self.assertEqual(button.text, 'Install')
+        self.assertEqual(button.text, 'Uninstall')
 
     def test_install_store_offering(self):
 
