@@ -49,6 +49,8 @@
         'StyledRadioButton': window.parent.StyledElements.StyledRadioButton,
         'StyledSelect': window.parent.StyledElements.StyledSelect,
         'StyledTextArea': window.parent.StyledElements.StyledTextArea,
+        'PaginatedSource': window.parent.StyledElements.PaginatedSource,
+        'PaginationInterface': window.parent.StyledElements.PaginationInterface,
         'StaticPaginatedSource': window.parent.StyledElements.StaticPaginatedSource,
         'MenuItem': window.parent.StyledElements.MenuItem,
         'ModelTable': window.parent.StyledElements.ModelTable,
@@ -68,7 +70,7 @@
         this.show = function show(refPosition) {
             var iwidget_object, position;
 
-            iwidget_object = platform.opManager.activeWorkspace.getIWidget(MashupPlatform.widget.id).content;
+            iwidget_object = platform.Wirecloud.activeWorkspace.getIWidget(MashupPlatform.widget.id).content;
             position = iwidget_object.getBoundingClientRect();
 
             refPosition = {
