@@ -41,7 +41,7 @@ var LayoutManagerFactory = function () {
         // *********************************
 
         this.mainLayout = new StyledElements.BorderLayout();
-        this.mainLayout.getNorthContainer().appendChild($('wirecloud_header'));
+        this.mainLayout.getNorthContainer().appendChild(document.getElementById('wirecloud_header'));
 
         this.alternatives = new StyledElements.StyledAlternatives();
         this.mainLayout.getCenterContainer().appendChild(this.alternatives);
@@ -50,118 +50,113 @@ var LayoutManagerFactory = function () {
         /* TODO| FIXME */
         this.header = new Wirecloud.ui.WirecloudHeader(this);
         this.alternatives.addEventListener('postTransition', function (alternatives, old_alternative, new_alternative) {
-            HistoryManager.pushState(new_alternative.buildStateData());
+            Wirecloud.HistoryManager.pushState(new_alternative.buildStateData());
             this.header._notifyViewChange(new_alternative);
         }.bind(this));
         this.viewsByName = {
+            'initial': this.alternatives.createAlternative(),
             'workspace': this.alternatives.createAlternative({'alternative_constructor': WorkspaceView}),
             'wiring': this.alternatives.createAlternative({'alternative_constructor': Wirecloud.ui.WiringEditor}),
             'marketplace': this.alternatives.createAlternative({'alternative_constructor': MarketplaceView})
         };
-        this.header._notifyViewChange(this.viewsByName['workspace']);
+        var plain_content = document.querySelector('.plain_content');
+        if (plain_content != null) {
+            this.viewsByName.initial.appendChild(plain_content);
+        }
 
-        // Container managed by LayOutManager: {showcase_tab}
-        // Remaining containers managed by Workspaces!!
         this._clickCallback = this._clickCallback.bind(this);
         this.timeout = null;
-        $("loading-window").observe('click', this._clickCallback);
+        if (document.getElementById("loading-window")) {
+            document.getElementById("loading-window").addEventListener('click', this._clickCallback, true);
+        }
 
-        // Menu Layer
-        this.currentMenu = null;                                // current menu (either dropdown or window)
-        this.coverLayerElement = $('menu_layer');               // disabling background layer
-        this.coverLayerElement.addClassName('disabled_background fade');
-
-        this.menus = new Array();
+        this.currentMenu = null;  // current root dialog
+        this.coverLayerElement = document.createElement('div');               // disabling background layer
+        this.coverLayerElement.id = 'menu_layer';
+        this.coverLayerElement.className = 'disabled_background fade';
+        this.coverLayerElement.style.display = 'none';
+        document.body.insertBefore(this.coverLayerElement, document.body.firstChild);
 
         // Listen to resize events
-        Event.observe(window, "resize", this.resizeWrapper.bind(this));
+        window.addEventListener("resize", this.resizeWrapper.bind(this), true);
     }
 
         // ***************
         // PUBLIC METHODS
         // ****************
 
+        var updateSubTaskProgress = function updateSubTaskProgress() {
+            this.subTask.updateTaskProgress(Math.round((this.currentStep * 100) / this.totalSteps));
+        };
 
-        LayoutManager.prototype._updateTaskProgress = function() {
-            var msg, subtaskpercentage, taskpercentage;
-
-            subtaskpercentage = Math.round((this.currentStep * 100) / this.totalSteps);
-            if (subtaskpercentage < 0) {
-                subtaskpercentage = 0;
-            } else if (subtaskpercentage > 100) {
-                subtaskpercentage = 100;
-            }
-
-            taskpercentage = (this.currentSubTask * 100) / this.totalSubTasks;
-            taskpercentage += subtaskpercentage * (1 / this.totalSubTasks);
-            taskpercentage = Math.round(taskpercentage);
-            if (taskpercentage < 0) {
-                taskpercentage = 0;
-            } else if (taskpercentage > 100) {
-                subtaskpercentage = 100;
-            }
+        var updateTaskProgress = function updateTaskProgress(monitor, progress) {
+            var msg;
 
             msg = gettext("%(task)s %(percentage)s%");
-            msg = interpolate(msg, {task: this.task, percentage: taskpercentage}, true);
-            $("loading-task-title").textContent = msg;
+            msg = interpolate(msg, {task: monitor.title, percentage: progress}, true);
+            document.getElementById("loading-task-title").textContent = msg;
 
-            if (this.subTask != "") {
+            if (monitor.subtasks.length === 0) {
+                msg = '';
+            } else if (monitor.subtasks[monitor.currentsubtask].title != "") {
                 msg = gettext("%(subTask)s: %(percentage)s%");
+                msg = interpolate(msg, {
+                    subTask: monitor.subtasks[monitor.currentsubtask].title,
+                    percentage: monitor.subtasks[monitor.currentsubtask].progress
+                }, true);
             } else {
-                msg = "%(subTask)s";
+                msg = "%(percentage)s";
+                msg = interpolate(msg, {
+                    percentage: monitor.subtasks[monitor.currentsubtask].progress
+                }, true);
             }
 
-            msg = interpolate(msg, {subTask: this.subTask, percentage: subtaskpercentage}, true);
-            $("loading-subtask-title").textContent = msg;
-        }
+            document.getElementById("loading-subtask-title").textContent = msg;
+        };
+
 
         LayoutManager.prototype._startComplexTask = function(task, subtasks) {
-            this.task = task ? task : "";
-            this.currentSubTask = -2;
-            this.totalSubTasks = subtasks != undefined ? subtasks : 1;
-            this.logSubTask("");
-            $("loading-window").removeClassName("disabled");
-        }
+            var monitor = new Wirecloud.TaskMonitorModel(task, subtasks);
+            document.getElementById("loading-window").classList.remove("disabled");
+
+            this.monitor = monitor; // TODO
+            this.monitor.addEventListener('progress', updateTaskProgress);
+            return monitor;
+        };
 
         LayoutManager.prototype.logSubTask = function(msg, totalSteps) {
-            this.subTask = msg ? msg : "";
-
-            if (msg) {
-                Wirecloud.GlobalLogManager.log(msg, Constants.Logging.INFO_MSG);
-            }
-
-            this.currentSubTask++;
-            if (this.currentSubTask >= this.totalSubTasks)
-                this.totalSubTasks = this.currentSubTask + 1;
+            this.subTask = this.monitor.nextSubtask(msg);
 
             this.currentStep = 0;
-            if (arguments.length == 2)
+            if (arguments.length == 2) {
                 this.totalSteps = totalSteps;
-            else
+            } else {
                 this.totalSteps = 1;
+            }
 
-            this._updateTaskProgress();
-        }
+            updateSubTaskProgress.call(this);
+        };
 
         LayoutManager.prototype.logStep = function(msg, totalSteps) {
-            //$("loading-step-title").textContent = msg ? msg : "";
             this.currentStep++;
-            if (this.currentStep > this.totalSteps)
+            if (this.currentStep > this.totalSteps) {
                 this.totalSteps = this.currentStep + 1;
+            }
 
-            if (arguments.length == 2)
+            if (arguments.length == 2) {
                 this.totalSteps = totalSteps;
+            }
 
-            this._updateTaskProgress();
-        }
+            updateSubTaskProgress.call(this);
+        };
 
         LayoutManager.prototype._hideProgressIndicator = function () {
-            var loadingElement = $("loading-window");
-            var loadingMessage = $("loading-message");
+            var loadingElement = document.getElementById("loading-window");
+            var loadingMessage = document.getElementById("loading-message");
 
-            loadingElement.addClassName('disabled');
-            loadingElement.removeClassName('fadding');
-            loadingMessage.setStyle({'opacity': '1'});
+            loadingElement.classList.add('disabled');
+            loadingElement.classList.remove('fadding');
+            loadingMessage.style.opacity = '1';
 
             if (this.timeout !== null) {
                 clearTimeout(this.timeout);
@@ -170,29 +165,24 @@ var LayoutManagerFactory = function () {
         };
 
         LayoutManager.prototype._clickCallback = function (event) {
-            event = event || window.event;
 
-            if ($("loading-window").hasClassName("fadding")) {
+            if (document.getElementById("loading-window").classList.contains("fadding")) {
                 this._hideProgressIndicator();
             }
-            if (event.stopPropagation) {
-                event.stopPropagation();
-            } else {
-                event.cancelBubble = true;
-            }
+            event.stopPropagation();
         };
 
         LayoutManager.prototype._notifyPlatformReady = function () {
-            var loadingElement = $("loading-window");
-            loadingElement.addClassName("fadding");
+            var loadingElement = document.getElementById("loading-window");
+            loadingElement.classList.add("fadding");
 
-            var loadingMessage = $("loading-message");
+            var loadingMessage = document.getElementById("loading-message");
             var step = 0;
             var layoutManager = this;
             function fadder() {
                 ++step;
                 if (step < 80) {
-                    loadingMessage.setStyle({'opacity': 1 - (step * 0.025)});
+                    loadingMessage.style.opacity = "" + (1 - (step * 0.025));
                     layoutManager.timeout = setTimeout(fadder, 50);
                 } else {
                     layoutManager._hideProgressIndicator();
@@ -204,9 +194,6 @@ var LayoutManagerFactory = function () {
             layoutManager.timeout = setTimeout(fadder, 50);
         }
 
-        LayoutManager.prototype.resizeContainer = function (container) {
-        }
-
         LayoutManager.prototype.resizeWrapper = function () {
             this.mainLayout.repaint();
 
@@ -216,14 +203,6 @@ var LayoutManagerFactory = function () {
             }
         }
 
-        LayoutManager.prototype.unloadCurrentView = function () {
-            if (this.currentView) {
-                this.currentView.hide();
-                this.currentView = null;
-            }
-        }
-
-
         /****VIEW OPERATIONS****/
         LayoutManager.prototype.changeCurrentView = function(newView) {
             this.alternatives.showAlternative(this.viewsByName[newView]);
@@ -233,14 +212,24 @@ var LayoutManagerFactory = function () {
          * Handler for changes in the hash to navigate to other areas
          */
         LayoutManager.prototype.onHashChange = function(state) {
-            var tab_id, tab, nextWorkspace, opManager, dragboard;
+            var tab_id, tab, nextWorkspace, opManager, dragboard, alert_msg;
 
             opManager = OpManagerFactory.getInstance();
 
             nextWorkspace = opManager.workspacesByUserAndName[state.workspace_creator][state.workspace_name];
-            if (nextWorkspace.getId() !== opManager.activeWorkspace.getId()) {
-                opManager.changeActiveWorkspace(nextWorkspace, state.tab);
-                return;
+            if (nextWorkspace == null) {
+                if (Wirecloud.activeWorkspace != null) {
+                    Wirecloud.activeWorkspace.unload();
+                    Wirecloud.activeWorkspace = null;
+                }
+                alert_msg = document.createElement('div');
+                alert_msg.className = 'alert alert-info';
+                alert_msg.textContent = gettext('The requested workspace is no longer available (it was deleted).');;
+                LayoutManagerFactory.getInstance().viewsByName['workspace'].clear();
+                LayoutManagerFactory.getInstance().viewsByName['workspace'].appendChild(alert_msg);
+                this.header.refresh();
+            } else if (Wirecloud.activeWorkspace == null || (nextWorkspace.id !== Wirecloud.activeWorkspace.id)) {
+                Wirecloud.changeActiveWorkspace(nextWorkspace, state.tab);
             }
 
             if (state.view !== this.alternatives.getCurrentAlternative().view_name) {
@@ -251,7 +240,7 @@ var LayoutManagerFactory = function () {
         LayoutManager.prototype.showUnclickableCover = function() {
             this.coverLayerElement.style.display = "block";
             setTimeout(function () {
-                this.coverLayerElement.addClassName('in');
+                this.coverLayerElement.classList.add('in');
             }.bind(this), 0);
         };
 
@@ -272,60 +261,16 @@ var LayoutManagerFactory = function () {
             this.currentMenu = window_menu;
         };
 
-        // Shows a generic alert dialog
-        LayoutManager.prototype.showAlertMessage = function(msg) {
-            // the disabling layer is displayed as long as a menu is shown. If there is not a menu, there is not a layer.
-            if (this.currentMenu != null) {//only if the layer is displayed.
-                this.hideCover();
-            }
-
-            this.showUnclickableCover();
-
-            this.currentMenu = new AlertWindowMenu();
-            this.currentMenu.setMsg(msg);
-            this.currentMenu.show();
-        }
-
-        /**
-         * Shows the message window menu using the specified text. By default,
-         * it will be interpreted as an information message, but you can use the
-         * type param to change this behaviour.
-         *
-         * @param {String} msg Text of the message to show
-         * @param {Constants.Logging} type Optional parameter to change the
-         *        message type. (default value: Constants.Logging.INFO_MSG)
-         */
-        LayoutManager.prototype.showMessageMenu = function(msg, type) {
-            var menu;
-            if (!this.menus['messageMenu']) {
-                this.menus['messageMenu'] = new Wirecloud.ui.MessageWindowMenu(null);
-            }
-            menu = this.menus['messageMenu'];
-
-            type = type ? type : Constants.Logging.INFO_MSG;
-            menu.setMsg(msg);
-            menu.setType(type);
-            // TODO: this.currentMenu???
-            menu.show(this.currentMenu);
-        }
-
         //hides the disabling layer and so, the current menu
         LayoutManager.prototype.hideCover = function() {
             if (this.currentMenu) {
                 this.currentMenu.hide();
             }
             this.currentMenu = null;
-            this.coverLayerElement.removeClassName('in');
+            this.coverLayerElement.classList.remove('in');
             this.coverLayerElement.style.display = "none";
         }
 
-        LayoutManager.prototype.FADE_TAB_INI = "#F0E68C";
-        LayoutManager.prototype.FADE_TAB_CUR_END = "#E0E0E0";
-        LayoutManager.prototype.FADE_TAB_END = "#97A0A8";
-        LayoutManager.prototype.IDENTIFIER_WIDTH = 550;
-        LayoutManager.prototype.SLIDER_WIDTH = 30;
-
-
     // *********************************
     // SINGLETON GET INSTANCE
     // *********************************
