@@ -183,7 +183,11 @@
 
         this.events.load.dispatch();
 
-        operators = Wirecloud.wiring.OperatorFactory.getAvailableOperators();
+        if (this.workspace.owned) {
+            operators = Wirecloud.wiring.OperatorFactory.getAvailableOperators();
+        } else {
+            operators = this.workspace.resources.getAvailableResourcesByType('operator');
+        }
         old_operators = this.ioperators;
         this.ioperators = {};
         for (id in status.operators) {
@@ -233,10 +237,11 @@
     };
 
     Wiring.prototype.save = function save() {
-        Wirecloud.io.makeRequest(Wirecloud.URLs.WIRING_ENTRY.evaluate({workspace_id: this.workspace.getId()}), {
+        Wirecloud.io.makeRequest(Wirecloud.URLs.WIRING_ENTRY.evaluate({workspace_id: this.workspace.id}), {
             method: 'PUT',
             contentType: 'application/json',
-            postBody: Object.toJSON(this.status)
+            requestHeaders: {'Accept': 'application/json'},
+            postBody: JSON.stringify(this.status)
         });
     };
 
@@ -264,7 +269,7 @@
         var id, msg, affected = false;
 
         for (id in this.ioperators) {
-            if (this.ioperators[id].meta.uri === operator.getURI()) {
+            if (this.ioperators[id].meta.uri === operator.uri) {
                 affected = true;
                 this.ioperators[id].destroy();
                 delete this.ioperators[id];
@@ -273,7 +278,7 @@
 
         if (affected) {
             msg = gettext('%(operator)s operator was removed while in use');
-            msg = interpolate(msg, {operator: operator.getURI()}, true);
+            msg = interpolate(msg, {operator: operator.uri}, true);
             this.events.error.dispatch(msg);
         }
     };
