@@ -1,4 +1,25 @@
-/*global EzWebExt, gettext, LayoutManagerFactory, OpManagerFactory, Variable, Wirecloud*/
+/*
+ *     Copyright 2012-2014 (c) CoNWeT Lab., Universidad Politécnica de Madrid
+ *
+ *     This file is part of Wirecloud Platform.
+ *
+ *     Wirecloud Platform is free software: you can redistribute it and/or
+ *     modify it under the terms of the GNU Affero General Public License as
+ *     published by the Free Software Foundation, either version 3 of the
+ *     License, or (at your option) any later version.
+ *
+ *     Wirecloud is distributed in the hope that it will be useful, but WITHOUT
+ *     ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ *     FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
+ *     License for more details.
+ *
+ *     You should have received a copy of the GNU Affero General Public License
+ *     along with Wirecloud Platform.  If not, see
+ *     <http://www.gnu.org/licenses/>.
+ *
+ */
+
+/*global gettext, LayoutManagerFactory, Wirecloud*/
 
 (function () {
 
@@ -11,7 +32,7 @@
 
         var fields, user_name, marketFields;
 
-        user_name = OpManagerFactory.getInstance().contextManager.get('username');
+        user_name = Wirecloud.contextManager.get('username');
         fields = [
             {
                 'type': 'group',
@@ -22,8 +43,8 @@
                     {name: 'version', label: gettext('Version'), type: 'version',  required: true},
                     {name: 'email', label: gettext('Email'), type: 'text',  required: true},
                     {name: 'description', label: gettext('Description'), type: 'longtext'},
-                    {name: 'doc_uri', label: gettext('Homepage'), type: 'text'},
-                    {name: 'author', label: gettext('Author'), type: 'text',  initialValue: user_name, defaultValue: user_name}
+                    {name: 'doc', label: gettext('Homepage'), type: 'text'},
+                    {name: 'authors', label: gettext('Author'), type: 'text',  initialValue: user_name, defaultValue: user_name}
                 ]
             },
             {
@@ -52,20 +73,19 @@
 
         //fill a warning message
         var warning = document.createElement('div');
-        warning.addClassName('alert');
+        warning.className = 'alert';
         warning.innerHTML = gettext("<strong>Warning!</strong> Configured and stored data in your workspace (properties and preferences except passwords) will be shared by default!");
         this.windowContent.insertBefore(warning, this.form.wrapperElement);
     };
     PublishWorkspaceWindowMenu.prototype = new Wirecloud.ui.FormWindowMenu();
 
     PublishWorkspaceWindowMenu.prototype._addVariableParametrization = function _addVariableParametrization(workspace, fields) {
-        var i, tab_keys, tab_field;
+        var key, tab_field;
 
         this.workspace = workspace;
-        tab_keys = workspace.tabInstances.keys();
 
-        for (i = 0; i < tab_keys.length; i += 1) {
-            tab_field = this._parseTab(workspace.tabInstances.get(tab_keys[i]));
+        for (key in workspace.tabInstances) {
+            tab_field = this._parseTab(workspace.tabInstances[key]);
             if (tab_field !== null) {
                 fields.push(tab_field);
             }
@@ -74,38 +94,34 @@
 
     PublishWorkspaceWindowMenu.prototype._parseTab = function _parseTab(tab) {
 
-        var i, name, iwidget, iwidgets, iwidget_params, pref_params,
-            prop_params, variable, variables, varManager, var_elements,
-            fields;
+        var i, j, iwidget, iwidgets, iwidget_params, pref_params,
+            prop_params, varManager, var_elements, fields;
 
         varManager = tab.workspace.getVarManager();
         iwidgets = tab.getDragboard().getIWidgets();
         fields = [];
 
         for (i = 0; i < iwidgets.length; i++) {
-            iwidget = iwidgets[i];
-            variables = varManager.getIWidgetVariables(iwidget.id);
+            iwidget = iwidgets[i].internal_iwidget;
             pref_params = [];
-            prop_params = [];
+            for (j = 0; j < iwidget.preferenceList.length; j += 1) {
+                pref_params.push({
+                    label: iwidget.preferenceList[j].label,
+                    type: 'parametrizableValue',
+                    variable: iwidget.preferenceList[j],
+                    canBeHidden: true,
+                    parentWindow: this
+                });
+            }
 
-            for (name in variables) {
-                variable = variables[name];
-                if (variable.vardef.aspect === Variable.prototype.USER_PREF) {
-                    pref_params.push({
-                        label: variable.getLabel(),
-                        type: 'parametrizableValue',
-                        variable: variable,
-                        canBeHidden: true,
-                        parentWindow: this
-                    });
-                } else if (variable.vardef.aspect === Variable.prototype.PROPERTY) {
-                    prop_params.push({
-                        label: variable.getLabel(),
-                        type: 'parametrizableValue',
-                        variable: variable,
-                        parentWindow: this
-                    });
-                }
+            prop_params = [];
+            for (j = 0; j < iwidget.propertyList.length; j += 1) {
+                prop_params.push({
+                    label: iwidget.preferenceList[i].meta.label,
+                    type: 'parametrizableValue',
+                    variable: iwidget.propertyList[j],
+                    parentWindow: this
+                });
             }
 
             var_elements = {};
@@ -113,7 +129,7 @@
                 var_elements.pref = {
                     label: gettext('Preferences'),
                     type: 'fieldset',
-                    fields: pref_params.sort(this._sortVariables)
+                    fields: pref_params
                 };
             }
             if (prop_params.length !== 0) {
@@ -151,11 +167,6 @@
         return var1.variable.vardef.order - var2.variable.vardef.order;
     };
 
-    PublishWorkspaceWindowMenu.prototype.show = function show(parentWindow) {
-        Wirecloud.ui.FormWindowMenu.prototype.show.call(this, parentWindow);
-        this.setValue(this.workspace.workspaceGlobalInfo.params);
-    };
-
     PublishWorkspaceWindowMenu.prototype.setFocus = function setFocus() {
         this.form.fieldInterfaces.name.focus();
     };
@@ -169,13 +180,13 @@
         };
 
         for (key in data) {
-            if (key.startsWith('tab-')) {
-                EzWebExt.merge(data.parametrization.iwidgets, data[key]);
+            if (Wirecloud.Utils.startsWith(key, 'tab-')) {
+                Wirecloud.Utils.merge(data.parametrization.iwidgets, data[key]);
                 delete data[key];
             }
         }
 
-        OpManagerFactory.getInstance().activeWorkspace.publish(data, {
+        Wirecloud.activeWorkspace.publish(data, {
             onFailure: function (msg) {
                 // TODO
                 this.form.pSetMsgs([msg]);
