@@ -18,7 +18,7 @@
  *     under the License.
  */
 
-/*global EzWebExt, StyledElements, Wirecloud */
+/*global StyledElements, Wirecloud */
 
 (function () {
 
@@ -63,7 +63,7 @@
             atr = '';
         }
 
-        this.canvasElement.setAttribute('class', EzWebExt.appendWord(atr, className));
+        this.canvasElement.setAttribute('class', Wirecloud.Utils.appendWord(atr, className));
     };
 
     /**
@@ -80,7 +80,7 @@
         arrow.redraw();
         arrow.insertInto(this.canvasElement.generalLayer);
 
-        if (extraClass != 'multiconnector_arrow') {
+        if ((extraClass != 'multiconnector_arrow') && extraClass != 'arrow hollow') {
             this.events.arrowadded.dispatch(this, arrow);
         }
         return arrow;
@@ -103,8 +103,9 @@
      * Clean the svg canvas.
      */
     Canvas.prototype.clear = function clear() {
+        this.canvasElement.classList.remove("elevated");
         while (this.canvasElement.generalLayer.childNodes.length > 0) {
-            this.canvasElement.generalLayer.removeChild(this.canvasElement.generalLayer.childNodes[0]);
+            this.canvasElement.generalLayer.removeChild(this.canvasElement.generalLayer.firstChild);
         }
     };
 
